#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-K7TFMjNYsftGGSWgQyqhww
key:                  coinbase-pro-0.9.3.2-K7TFMjNYsftGGSWgQyqhww
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  223f7b754dbd5773098ee9dd03956709
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-K7TFMjNYsftGGSWgQyqhww
depends:
    HsOpenSSL-0.11.7.10-6hHqFSiOfZ6Fry6FGRDGrR
    aeson-2.2.2.0-6vy5nFkYOklEBUzF5CRv7u
    aeson-casing-0.2.0.0-F4bbTJlNB1SG4tnh73DQI2
    async-2.2.6-FyNZXdji95t98VleCj3HXu base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-DDxFsbgl8m96PV8Uy6qQgt exceptions-0.10.7
    http-api-data-0.6.1-EiZXvfA383DCaF3oPI1tFk
    http-client-0.7.19-8AzWSyA06XNDCM9FIBhhTj
    http-client-tls-0.3.6.4-GpdGf98kidO2rAaJB77bKV
    http-streams-0.8.9.9-3OcbpEJrpMYHnWWG0quT8R
    http-types-0.12.4-AW38QdPURmwEzxajknpV4M
    io-streams-1.5.2.2-LHqqHouSGT6kQXy217AVB
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8HZ2mHT7KyE1ZVQfwLbJCE
    servant-0.20.3.0-K56ddADEp44L5TJx7R7G4q
    servant-client-0.20.3.0-3qIKcW0CeC0FdusCr7EcSu
    servant-client-core-0.20.3.0-3z6mm3jud2OFYUISDmDU1T
    tasty-1.5.4-7y5W1ew2ZKj75dqOBUo0NY
    tasty-hunit-0.10.2-F7OiIFJ0eY2A5nPfcJ9IKy text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-8F6UPO5rQbFEIagqtrQ1bJ
    unordered-containers-0.2.21-CG6y7kseADB9y4YJD0dypo
    uuid-1.3.16.1-DPU1pyFvmFvGXgW1eSh0Oa
    vector-0.13.2.0-8P1yhfNTE0VJ5EIM0TMJkk
    websockets-0.12.7.3-3SiKbiFv2Sd4VdHTQL4V3H
    wuss-2.0.1.7-9QLXoKCGbyVLXV44f9IBgH

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

